@@ -118,6 +118,10 @@ sub read_config {
 							   bionic
 						           cosmic
 							   disco
+							   eoan
+							   focal
+							   groovy
+							   hirsute
 						      )),
 		  user => $>,
 
@@ -176,7 +180,7 @@ sub read_config {
 							  \.template
 							)
 						      ) .')$',
-		  pdiff_files_regexp => '(?:^|/)2\d{3}-\d{2}-\d{2}-\d{4}\.\d{2}\.gz$',
+		  pdiff_files_regexp => '(?:^|/)(?:T-2\d{3}-\d{2}-\d{2}-\d{4}\.\d{2}-F-)?2\d{3}-\d{2}-\d{2}-\d{4}\.\d{2}\.gz$',
 		  soap_url_regexp => '^(?:http://)?bugs\.debian\.org(?::80)?/cgi-bin/soap\.cgi$',
 		 );
 
